@@ -1,7 +1,7 @@
 context("US Counties")
 
 test_that("No date returns current counties", {
-  expect_identical(us_counties(), USAboundaries::cb_2014_us_county_20m)
+  expect_identical(us_counties(), USAboundariesData::counties_contemporary_lores)
 })
 
 test_that("Dates outside the valid range have an error message", {
@@ -10,17 +10,17 @@ test_that("Dates outside the valid range have an error message", {
 })
 
 test_that("Current states can be filtered", {
-  expect_equal(length(us_counties(states = c("Virginia"))), 133)
+  expect_equal(nrow(us_counties(states = c("Virginia"))), 133)
 })
 
 test_that("Historical states can be filtered", {
-  expect_equal(length(us_counties("1855-01-02", states = c("Ohio"))), 88)
+  expect_equal(nrow(us_counties("1855-01-02", states = c("OH"))), 88)
 })
 
 test_that("Correct resolution shapefiles are returned", {
   skip_if_not_installed("USAboundariesData")
   expect_identical(us_counties(resolution = "low"),
-                   USAboundaries::cb_2014_us_county_20m)
+                   USAboundariesData::counties_contemporary_lores)
   expect_identical(us_counties(resolution = "high"),
-                   USAboundariesData::cb_2014_us_county_500k)
+                   USAboundariesData::counties_contemporary_hires)
 })
